==> nextcloud-app-news-1%3A25.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/af.js <==
OC.L10N.register(
    "news",
    {
    "News" : "Nuus",
    "Shared with me" : "Gedeel met my",
    "Download" : "Laai Af",
    "Close" : "Sluit",
    "Web address" : "Webadres",
    "No folder" : "Geen vouer",
    "Folder name" : "Vouernaam",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "New folder" : "Nuwe vouer",
    "Folder exists already!" : "Vouers bestaan reeds!",
    "Subscribe" : "Teken in",
    "Move" : "Skuif",
    "Share" : "Deel",
    "All articles" : "Alle artikels",
    "Explore" : "Ontdek",
    "Settings" : "Instellings",
    "Keyboard shortcuts" : "Sneltoetse",
    "Rename" : "Hernoem",
    "Delete" : "Skrap",
    "Newest first" : "Nuutste eerste",
    "Oldest first" : "Oudste eerste",
    "by" : "deur",
    "from" : "van",
    "Play audio" : "Speel oudio af",
    "Download audio" : "Laai oudio af",
    "Download video" : "Laai video af",
    "Keyboard shortcut" : "Snelsleutel",
    "right" : "regs",
    "Jump to next article" : "Spring na volgende artikel",
    "left" : "links",
    "Jump to previous article" : "Spring na vorige artikel",
    "Refresh" : "Verfris",
    "Description" : "Beskrywing",
    "Folder" : "Vouer",
    "Go back" : "Gaan terug",
    "New Folder" : "Nuwe Vouer",
    "Create" : "Skep",
    "Menu" : "Kieslys",
    "Dismiss" : "Wys Af",
    "Collapse" : "Vou In",
    "Deleted folder" : "Geskrapte vouer",
    "Import" : "Voer In",
    "Export" : "Stuur Uit",
    "Help" : "Hulp",
    "Documentation" : "Dokumentasie"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1%3A25.3.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/af.js <==
OC.L10N.register(
    "news",
    {
    "News" : "Nuus",
    "Shared with me" : "Gedeel met my",
    "Download" : "Laai Af",
    "Close" : "Sluit",
    "Web address" : "Webadres",
    "No folder" : "Geen vouer",
    "Folder name" : "Vouernaam",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "New folder" : "Nuwe vouer",
    "Folder exists already!" : "Vouers bestaan reeds!",
    "Subscribe" : "Teken in",
    "Move" : "Skuif",
    "Share" : "Deel",
    "All articles" : "Alle artikels",
    "Explore" : "Ontdek",
    "Settings" : "Instellings",
    "Documentation" : "Dokumentasie",
    "Keyboard shortcuts" : "Sneltoetse",
    "Rename" : "Hernoem",
    "Delete" : "Skrap",
    "Newest first" : "Nuutste eerste",
    "Oldest first" : "Oudste eerste",
    "Previous" : "Vorige",
    "by" : "deur",
    "from" : "van",
    "Play audio" : "Speel oudio af",
    "Download audio" : "Laai oudio af",
    "Download video" : "Laai video af",
    "Keyboard shortcut" : "Snelsleutel",
    "Jump to next article" : "Spring na volgende artikel",
    "Jump to previous article" : "Spring na vorige artikel",
    "right" : "regs",
    "left" : "links",
    "Refresh" : "Verfris",
    "Description" : "Beskrywing",
    "Folder" : "Vouer",
    "Go back" : "Gaan terug",
    "New Folder" : "Nuwe Vouer",
    "Create" : "Skep",
    "Menu" : "Kieslys",
    "Dismiss" : "Wys Af",
    "Collapse" : "Vou In",
    "Deleted folder" : "Geskrapte vouer",
    "Import" : "Voer In",
    "Export" : "Stuur Uit",
    "Help" : "Hulp"
},
"nplurals=2; plural=(n != 1);");
